#
# spec file for package libapreq2
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           libapreq2-3
Version:        2.13
Release:        8.52
Summary:        Safe, Standards-compliant, High-Performance Library for HTTP
License:        Apache Software License version 2.0 (ASL v2.0)
Group:          System/Libraries
Url:            http://httpd.apache.org/apreq
# http://mirrors.isc.org/pub/apache/httpd/libapreq/libapreq2-%{version}.tar.gz
Source:         libapreq2-%{version}.tar.bz2
Patch1:         libapreq2-mod_perl_include.patch
Patch2:         libapreq2-perl_install_vendor.patch
Patch3:         libapreq2-fix_config.patch
BuildRequires:  apache2-devel apache-rpm-macros
BuildRequires:  apache2-mod_perl-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  apr-util-devel
BuildRequires:  apr-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  openldap2-devel
BuildRequires:  perl
BuildRequires:  perl-ExtUtils-XSBuilder
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1020
BuildRequires:  libexpat-devel
%else
BuildRequires:  expat
%endif

%description
httpd-apreq is subproject of the Apache HTTP Server Project whose committers
develop and maintain the libapreq C library and its language bindings for Perl
(contributions for additional language bindings are most welcome).

libapreq is a safe, standards-compliant, high-performance library used for
parsing HTTP cookies, query-strings and POST data.

%package -n libapreq2-devel
Summary:        Safe, Standards-compliant, High-Performance Library for HTTP
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       glibc-devel
Requires:       libapr-util1-devel
Requires:       libapr1-devel
Provides:       %{name}-devel = %{version}-%{release}
%if 0%{?suse_version} > 1020
Requires:       libexpat-devel
%else
Requires:       expat
%endif

%description -n libapreq2-devel
httpd-apreq is subproject of the Apache HTTP Server Project whose committers
develop and maintain the libapreq C library and its language bindings for Perl
(contributions for additional language bindings are most welcome).

libapreq is a safe, standards-compliant, high-performance library used for
parsing HTTP cookies, query-strings and POST data.

%package -n apache2-mod_apreq2
Summary:        Filter Module for Apache2 based on libapreq2
Group:          Productivity/Networking/Web/Servers
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       %{name} = %{version}-%{release}
Requires:       apache2

%description -n apache2-mod_apreq2
Filter module for Apache2, based on libapreq2.

%package -n apache2-mod_apreq2-devel
Summary:        Filter Module for Apache2 based on libapreq2
Group:          Development/Libraries/C and C++
Requires:       apache2-devel
Requires:       libapreq2-devel = %{version}-%{release}

%description -n apache2-mod_apreq2-devel
Filter module for Apache2, based on libapreq2.
This package contains the header.

%package -n perl-Apache2-Request
Summary:        Perl Bindings for libapreq2
Group:          Productivity/Networking/Web/Servers
Provides:       perl-Apache2-Cookie = %{version}-%{release}
Provides:       perl-Apache2-Upload = %{version}-%{release}
Provides:       perl-APR-Request = %{version}-%{release}

%description -n perl-Apache2-Request
Apache mod_perl2 bindings for libapreq2.

%prep
%setup -q -n "libapreq2-%{version}"
%patch1
%patch2
cp apreq2-config.in apreq2-config-build.in
%patch3

%build
%configure \
    --with-perl=perl \
    --enable-perl-glue \
    --with-apache2-apxs=%{apache_apxs}
make %{?_smp_mflags} apreq2-config
mv apreq2-config apreq2-config-dist
mv apreq2-config-build.in apreq2-config.in
make %{?_smp_mflags} apreq2-config

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm "%{buildroot}%{_libdir}/apache2"/*.{a,la}
rm "%{buildroot}%{_bindir}/apreq2-config"
install -m0755 apreq2-config-dist "%{buildroot}%{_bindir}/apreq2-config"

%perl_process_packlist

%if 0%{?suse_version} >= 1140
rm -rf %{buildroot}%{_localstatedir}/adm/perl-modules
%endif

install -d "%{buildroot}%{_libdir}/pkgconfig"
cat<<EOF >"%{buildroot}%{_libdir}/pkgconfig/apreq2.pc"
prefix=%{_prefix}
exec_prefix=%{_exec_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

Name:           libapreq2
Description:    Library for parsing HTTP cookies, query-strings and POST data
Version:        %{version}
Requires:       apr-1 apr-util-1
Libs:           -L${libdir} -lapreq2
Cflags:         -I${includedir}
EOF


%check
set +x
mkdir -p %{apache_test_module_dir}
# mod_apreq2.so export mod_apreq, not mod_apreq2, need
# to load module manually (not via -m to %%apache_test_module_load)
cat << EOF > %{apache_test_module_dir}/mod_apreq2.conf
LoadModule mod_apreq %{buildroot}/usr/lib64/mod_apreq2.so
EOF
export LD_LIBRARY_PATH="%{buildroot}/usr/lib64:$LD_LIBRARY_PATH"
%apache_test_module_load
set -x


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc CHANGES LICENSE README STATUS NOTICE
%{_libdir}/libapreq2.so.3
%{_libdir}/libapreq2.so.3.*.*

%files -n libapreq2-devel
%defattr(-,root,root)
%{_bindir}/apreq2-config
%{_includedir}/apreq2
%{_libdir}/libapreq2.so
%{_libdir}/libapreq2.a
%{_libdir}/libapreq2.la
%{_libdir}/pkgconfig/apreq2.pc

%files -n apache2-mod_apreq2
%defattr(-,root,root)
%dir %{apache_libexecdir}
%{apache_libexecdir}/mod_apreq2.so

%files -n apache2-mod_apreq2-devel
%defattr(-,root,root)
%dir %{_includedir}/apache2
%{_includedir}/apache2/apreq2

%files -n perl-Apache2-Request
%defattr(-,root,root)
%dir %{perl_vendorarch}/Apache2
%{perl_vendorarch}/Apache2/Cookie.pm
%{perl_vendorarch}/Apache2/Request.pm
%{perl_vendorarch}/Apache2/Upload.pm
%dir %{perl_vendorarch}/APR
#%{perl_vendorarch}/APR/DummyVersions.pm
%{perl_vendorarch}/APR/Request.pm
%{perl_vendorarch}/APR/Request.pod
%dir %{perl_vendorarch}/APR/Request
%{perl_vendorarch}/APR/Request/*.pm
%{perl_vendorarch}/APR/Request/*.pod
%dir %{perl_vendorarch}/auto/APR
%dir %{perl_vendorarch}/auto/APR/Request
%{perl_vendorarch}/auto/APR/Request/*
%dir %{perl_vendorarch}/auto/libapreq2
%doc %{perl_man3dir}/Apache2::Cookie.%{perl_man3ext}*
%doc %{perl_man3dir}/Apache2::Request.%{perl_man3ext}*
%doc %{perl_man3dir}/Apache2::Upload.%{perl_man3ext}*
%doc %{perl_man3dir}/APR::Request.%{perl_man3ext}*
%doc %{perl_man3dir}/APR::Request::*.%{perl_man3ext}*
%if 0%{?suse_version} <= 1130
%{perl_vendorarch}/auto/libapreq2/.packlist
%{_localstatedir}/adm/perl-modules/libapreq2-3
%endif

%changelog
* Tue Dec 19 2017 pgajdos@suse.com
- buildrequire apr-devel instead of libapr1-devel
- buildrequire apr-util-devel instead of libapr-util1-devel
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Thu Oct 30 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Wed Mar  2 2011 draht@suse.de
- /var/adm/perl-modules/libapreq2-3 added for < 11.4.
  %%{perl_vendorarch}/auto/libapreq2/.packlist added
* Thu Dec  2 2010 pascal.bleser@opensuse.org
- update to 2.13:
  * HTTP Only Cookie
* Wed Apr 15 2009 pascal.bleser@opensuse.org
- new package
